@@ -185,7 +185,7 @@ usage(const bool error)
 void
 version(void)
 {
-	puts("confget 2.2.0");
+	puts("confget " VERSION_STRING);
 }
 
 /***
@@ -334,7 +334,7 @@ init(const int argc, char * const * const argv)
 	margc = argc - optind;
 	margv = argv + optind;
 	const char * const features[][2] = {
-		{ "BASE", "2.1" },
+		{ "BASE", VERSION_STRING },
 		{ NULL, NULL },
 	};
 	if (qsections + qfeature + qfeatures + lflag + Lflag +
