@@ -1,4 +1,4 @@
-# Copyright (c) 2018, 2019  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2020  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -22,9 +22,7 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-"""
-Utility functions for the confget test cases.
-"""
+"""Utility functions for the confget test cases."""
 
 import re
 
@@ -34,7 +32,7 @@ _RE_APOS = re.compile("(?P<pre> [^']* ) (?P<apos> '+ ) (?P<post> .* )", re.X)
 
 def shell_escape(value):
     # type: (str) -> str
-    """ Escape a value for the shell. """
+    """Escape a value for the shell."""
     res = "'"
     while True:
         match = _RE_APOS.match(value)
