@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 #
-# Copyright (c) 2018, 2019  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2020  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -24,14 +24,12 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
-"""
-Generate shell scripts with TAP output for the confget tests.
-"""
+"""Generate shell scripts with TAP output for the confget tests."""
 
 from typing import List
 
-from unit_tests.data import defs as t_defs
-from unit_tests.data import load as t_load
+from unit_tests.data import test_defs as t_defs
+from unit_tests.data import test_load as t_load
 from unit_tests.data import util as t_util
 
 
@@ -74,8 +72,10 @@ if [ ! -f "$TESTDIR/{fname}" ]; then
 fi"""
 
 
-def add_cmdline_options(cmdline: List[str], test: t_defs.TestDef) -> None:
-    """ Add the options from test.args into cmdline. """
+def add_cmdline_options(
+    cmdline: List[str], test: t_defs.SingleTestDef
+) -> None:
+    """Add the options from test.args into cmdline."""
     for name, value in test.args.items():
         option = t_defs.CMDLINE_OPTIONS[name]
         if option[0] == "":
@@ -89,7 +89,7 @@ def add_cmdline_options(cmdline: List[str], test: t_defs.TestDef) -> None:
 
 
 def main() -> None:
-    """ Main function: generate the test files. """
+    """Main function: generate the test files."""
     tests = t_load.load_all_tests(".")
     for fname, data in sorted(tests.items()):
         print(f"Generating {fname}.t with {len(data.tests)} tests")
